aboutsummaryrefslogtreecommitdiff
path: root/gdb/symtab.h
diff options
context:
space:
mode:
authorDaniel Jacobowitz <drow@false.org>2007-01-04 20:26:42 +0000
committerDaniel Jacobowitz <drow@false.org>2007-01-04 20:26:42 +0000
commit303b6f5dea757484ac8074bee1b4d5f7c897a997 (patch)
tree0ae6c7a147525bc1204424559e035ade47febafe /gdb/symtab.h
parent2d0720d988230d947d5eee9245a7d2fc3f0eeb0a (diff)
downloadgdb-303b6f5dea757484ac8074bee1b4d5f7c897a997.zip
gdb-303b6f5dea757484ac8074bee1b4d5f7c897a997.tar.gz
gdb-303b6f5dea757484ac8074bee1b4d5f7c897a997.tar.bz2
* buildsym.c (start_subfile): Handle producer.
(record_producer): New function. * buildsym.h (struct subfile): Include producer. (record_producer): New prototype. * dwarf2-frame.c (struct dwarf2_cie): Add version and augmentation. (struct dwarf2_frame_state): Add armcc_cfa_offsets_sf and armcc_cfa_offsets_reversed. (execute_cfa_program): Handle armcc_cfa_offsets_sf. (dwarf2_frame_find_quirks): New function. (dwarf2_frame_cache): Call it. Handle armcc_cfa_offsets_reversed. (decode_frame_entry_1): Record the CIE version. Record the augmentation. Skip armcc augmentations. * dwarf2read.c (read_file_scope): Save the producer. * symtab.h (struct symtab): Rename unused version member to producer.
Diffstat (limited to 'gdb/symtab.h')
-rw-r--r--gdb/symtab.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gdb/symtab.h b/gdb/symtab.h
index 4a980c1..1d72c84 100644
--- a/gdb/symtab.h
+++ b/gdb/symtab.h
@@ -846,9 +846,9 @@ struct symtab
char *debugformat;
- /* String of version information. May be zero. */
+ /* String of producer version information. May be zero. */
- char *version;
+ char *producer;
/* Full name of file as found by searching the source path.
NULL if not yet known. */